Struct XdgShell
pub struct XdgShell { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
The xdg shell globals.
Implementations
impl XdgShell
impl XdgShell
pub const API_VERSION_MAX: u32 = 6u32
pub const API_VERSION_MAX: u32 = 6u32
The maximum API version for XdgWmBase that this object will bind.
pub fn bind<State>(
globals: &GlobalList,
qh: &QueueHandle<State>,
) -> Result<XdgShell, BindError>where
State: Dispatch<XdgWmBase, GlobalData> + Dispatch<ZxdgDecorationManagerV1, GlobalData> + 'static,
pub fn bind<State>(
globals: &GlobalList,
qh: &QueueHandle<State>,
) -> Result<XdgShell, BindError>where
State: Dispatch<XdgWmBase, GlobalData> + Dispatch<ZxdgDecorationManagerV1, GlobalData> + 'static,
pub fn create_window<State>(
&self,
surface: impl Into<Surface>,
decorations: WindowDecorations,
qh: &QueueHandle<State>,
) -> Windowwhere
State: Dispatch<XdgSurface, WindowData> + Dispatch<XdgToplevel, WindowData> + Dispatch<ZxdgToplevelDecorationV1, WindowData> + WindowHandler + 'static,
pub fn create_window<State>(
&self,
surface: impl Into<Surface>,
decorations: WindowDecorations,
qh: &QueueHandle<State>,
) -> Windowwhere
State: Dispatch<XdgSurface, WindowData> + Dispatch<XdgToplevel, WindowData> + Dispatch<ZxdgToplevelDecorationV1, WindowData> + WindowHandler + 'static,
Creates a new, unmapped window.
Protocol errors
If the surface already has a role object, the compositor will raise a protocol error.
A surface is considered to have a role object if some other type of surface was created using the surface. For example, creating a window, popup, layer or subsurface all assign a role object to a surface.
This function takes ownership of the surface.
For more info related to creating windows, see the module documentation.
pub fn xdg_wm_base(&self) -> &XdgWmBase