Struct XdgShellSurface

pub struct XdgShellSurface { /* private fields */ }
Available on crate feature wayland and Linux only.
A surface role for functionality common in desktop-like surfaces.

Implementations



impl XdgShellSurface

pub fn new<U, D>( wm_base: &impl ProvidesBoundGlobal<XdgWmBase, smithay_client_toolkit::::shell::xdg::{impl#5}::new::{constant#0}>, qh: &QueueHandle<D>, surface: impl Into<Surface>, udata: U, ) -> Result<XdgShellSurface, GlobalError>
where D: Dispatch<XdgSurface, U> + 'static, U: Send + Sync + 'static,

Creates an XdgShellSurface.

This function is generally intended to be called in a higher level abstraction, such as XdgShell::create_window.

The created XdgShellSurface will destroy the underlying XdgSurface or WlSurface when dropped. Higher level abstractions are responsible for ensuring the destruction order of protocol objects is correct. Since this function consumes the WlSurface, it may be accessed using XdgShellSurface::wl_surface.

Protocol errors

If the surface already has a role object, the compositor will raise a protocol error.

A surface is considered to have a role object if some other type of surface was created using the surface. For example, creating a window, popup, layer, subsurface or some other type of surface object all assign a role object to a surface.

pub fn xdg_surface(&self) -> &XdgSurface

pub fn wl_surface(&self) -> &WlSurface